<?php

  /*
   Plugin Name: Schattenzeilen Feed
   Plugin URI: https://www.schattenzeilen.de/newsfeed.php
   Description: Dieses Plugin stellt einen Feed der Schattenzeilen dar. Ein Widget für die Sidebar.
   Version: 0.201708231921
   Author: Schattenzeilen
   Author URI: http://www.schattenzeilen.de
   License: GPL2
   */

class Schattenzeilen_Widget extends WP_Widget {


/**
 * Register widget with WordPress.
 */
    public function __construct() {
		parent::__construct(
	 		'schattenzeilen_feed', // Base ID
			'Schattenzeilen Feed', // Name
			array( 'description' => __( 'Mit diesem Widget kannst du alle Neuigkeiten oder die neuesten Texte der Schattenzeilen auf deiner Webseite anzeigen.', 'evolution_schattenzeilen' ), ) // Args
		);

		// Adding the javascript only if widget in use
		if ( is_active_widget( false, false, $this->id_base, true ) ) {

			wp_enqueue_script('widgets');

		}
	}	

	
	
    /**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
    public function widget($args, $instance) {  	
    	
    	//global $app_id;
        extract( $args );
        
		$widget_headline	= apply_filters('widget_title', $instance['widget_headline']);
		
		$widget_feed		= $instance['widget_feed'];
		
		switch ($widget_feed):
			case "Neuigkeiten":	$xmlfile = 'https://www.schattenzeilen.de/newsfeed.xml';
								break;
			case "Neue Texte":	$xmlfile = 'https://www.schattenzeilen.de/storyfeed.xml';
								break;
			default:			$xmlfile = 'https://www.schattenzeilen.de/newsfeed.xml';
								break;
		endswitch;					
		
		$widget_items	= $instance['widget_items'];
		if (!$widget_items):
			$widget_items = 3;
		endif;
		settype($widget_items, 'integer');
		if ($widget_items<1):
			$widget_items = 1;
		endif;
		
		$widget_size_headline	= $instance['widget_size_headline'];
		$widget_size_text		= $instance['widget_size_text'];
		$widget_images			= $instance['widget_images'];
		
		
		echo $before_widget;
        if ( $widget_headline )
			echo $before_title . $widget_headline . $after_title;

 		
		
		// Feed einlesen
		if( !$xml = simplexml_load_file($xmlfile) ):
			die('Fehler beim Einlesen des Feeds!');
		endif;

		// Ausgabe Array
		$out = array();

		// auszulesende Datensätze
		$i = $widget_items;

		// Items vorhanden?
		if( !isset($xml->channel[0]->item) ) {
			die('Keine Einträge vorhanden.');
		}

		// Items holen
		foreach($xml->channel[0]->item as $item) {
		
			$item_timestamp = date('U', strtotime((string) $item->pubDate));
			
			$out[$item_timestamp] = array(
				'title'        => (string) $item->title,
				'description'  => (string) $item->description,
				'link'         => (string) $item->guid,
				'date'         => date('d.m.Y H:i', strtotime((string) $item->pubDate))
			);
		}

		
		// Array nach Schlüssel sortieren
		krsort( $out);
		
		// Array auf Anzahl gewünschter Artikel begrenzen
		$out = array_slice($out, 0, $widget_items);
		
		
		// Tags für Größe der Überschrift
		switch ($widget_size_headline):
			case 'Sehr Klein':	$widget_size_headline_str = "x-small";
								break;
			case 'Klein':		$widget_size_headline_str = "small";
								break;
			case 'Mittel':		$widget_size_headline_str = "medium";
								break;
			case 'Gross':		$widget_size_headline_str = "large";
								break;
			default:			$widget_size_headline_str = "medium";
								break;
		endswitch;
		
		// Tags für Größe der Texte
		switch ($widget_size_text):
			case 'Sehr Klein':	$widget_size_text_str = "x-small";
								break;
			case 'Klein':		$widget_size_text_str = "small";
								break;
			case 'Mittel':		$widget_size_text_str = "medium";
								break;
			case 'Gross':		$widget_size_text_str = "large";
								break;
			default:			$widget_size_text_str = "medium";
								break;
		endswitch;
		
		
		// Einträge ausgeben
		foreach ($out as $value) {
			
			echo "<div>";
			
			echo "<p><".$widget_size_headline_str."><a href='".$value['link']."' title='".$value['title']."' target='_new'>".$value['title']."</a></".$widget_size_headline_str."></p>";
		
			// Bilder aus Text entfernen
			if ($widget_images == 'Nein'):
				$pattern = '/<img[^>]+\>/i';
				$value['description'] = preg_replace($pattern, '', $value['description']);
			endif;
		
			echo "<p><".$widget_size_text_str.">".$value['description']." <a href='".$value['link']."' title='".$value['title']."' target='_new'>Lesen...</a></".$widget_size_text_str."></p>";
			
			echo "</div>";
			
			echo "<div style='clear: both; zoom: 1;'><hr></div>";
			
		}
		 
 		echo $after_widget;

	} 


    /**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
    public function update( $new_instance, $old_instance ) {

		$instance = array();
		$instance['widget_headline']		= strip_tags( $new_instance['widget_headline'] );
		$instance['widget_feed']			= strip_tags( $new_instance['widget_feed'] );
		$instance['widget_items']			= strip_tags( $new_instance['widget_items'] );
		$instance['widget_size_headline']	= strip_tags( $new_instance['widget_size_headline'] );
		$instance['widget_size_text']		= strip_tags( $new_instance['widget_size_text'] );
		$instance['widget_images']			= strip_tags( $new_instance['widget_images'] );
		
		return $instance;

	}


    /**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
    public function form($instance) {

    	/**
    	 * Set Default Value for widget form
    	 */   	
    	$default_value	=	array("widget_headline"=> "Schattenzeilen", "widget_feed" => "Neuigkeiten", "widget_items" => "3", "widget_size_headline" => "Mittel", "widget_size_text" => "Klein", "widget_images" => "Nein" );
    	
		$instance		=	wp_parse_args((array)$instance,$default_value);
        
    	$widget_headline		= esc_attr($instance['widget_headline']);
		$widget_feed			= esc_attr($instance['widget_feed']);
		$widget_items			= esc_attr($instance['widget_items']);
        $widget_size_headline	= esc_attr($instance['widget_size_headline']);
		$widget_size_text		= esc_attr($instance['widget_size_text']);
		$widget_images			= esc_attr($instance['widget_images']);
        	
		?>
		
		<!-- Formularfeld für widget_headline -->
		<p>
			<label for="<?php echo $this->get_field_id('widget_headline'); ?>"><?php _e('Titel:', 'evolution_schattenzeilen'); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id('widget_headline'); ?>" name="<?php echo $this->get_field_name('widget_headline'); ?>" type="text" value="<?php echo $widget_headline; ?>" />
        </p>
		
		
		<!-- Formularfeld für widget_feed -->
		<p>
			<label for="<?php echo $this->get_field_id('widget_feed'); ?>"><?php _e('Anzeige:', 'evolution_schattenzeilen'); ?></label>
			<select name="<?php echo $this->get_field_name('widget_feed'); ?>" id="<?php echo $this->get_field_id('widget_feed'); ?>" class="widefat">
				<option value="Neuigkeiten"<?php selected( $instance['widget_feed'], 'Neuigkeiten' ); ?>><?php _e('Neuigkeiten'); ?></option>
				<option value="Neue Texte"<?php selected( $instance['widget_feed'], 'Neue Texte' ); ?>><?php _e('Neue Texte'); ?></option>
			</select>
        </p> 
		
		
		<!-- Formularfeld für widget_items -->
		<p>
			<label for="<?php echo $this->get_field_id('widget_items'); ?>"><?php _e('Artikel:', 'evolution_schattenzeilen'); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id('widget_items'); ?>" name="<?php echo $this->get_field_name('widget_items'); ?>" type="text" value="<?php echo $widget_items; ?>" />
        </p>
		
        
		<!-- Formularfeld für widget_size_headline -->
        <p>
			<label for="<?php echo $this->get_field_id('widget_size_headline'); ?>"><?php _e('Größe Überschriften:', 'evolution_schattenzeilen'); ?></label>
			<select name="<?php echo $this->get_field_name('widget_size_headline'); ?>" id="<?php echo $this->get_field_id('widget_size_headline'); ?>" class="widefat">
				<option value="Sehr klein"<?php selected( $instance['widget_size_headline'], 'Sehr klein' ); ?>><?php _e('Sehr klein'); ?></option>
				<option value="Klein"<?php selected( $instance['widget_size_headline'], 'Klein' ); ?>><?php _e('Klein'); ?></option>
				<option value="Mittel"<?php selected( $instance['widget_size_headline'], 'Mittel' ); ?>><?php _e('Mittel'); ?></option>
				<option value="Gross"<?php selected( $instance['widget_size_headline'], 'Gross' ); ?>><?php _e('Gross'); ?></option>
			</select>
        </p> 
		
		
		<!-- Formularfeld für widget_size_text -->
        <p>
			<label for="<?php echo $this->get_field_id('widget_size_text'); ?>"><?php _e('Größe Text:', 'evolution_schattenzeilen'); ?></label>
			<select name="<?php echo $this->get_field_name('widget_size_text'); ?>" id="<?php echo $this->get_field_id('widget_size_text'); ?>" class="widefat">
				<option value="Sehr klein"<?php selected( $instance['widget_size_text'], 'Sehr klein' ); ?>><?php _e('Sehr klein'); ?></option>
				<option value="Klein"<?php selected( $instance['widget_size_text'], 'Klein' ); ?>><?php _e('Klein'); ?></option>
				<option value="Mittel"<?php selected( $instance['widget_size_text'], 'Mittel' ); ?>><?php _e('Mittel'); ?></option>
				<option value="Gross"<?php selected( $instance['widget_size_text'], 'Gross' ); ?>><?php _e('Gross'); ?></option>
			</select>
        </p>
		
		
		<!-- Formularfeld für widget_images -->
        <p>
			<label for="<?php echo $this->get_field_id('widget_images'); ?>"><?php _e('Bilder anzeigen:', 'evolution_schattenzeilen'); ?></label>
			<select name="<?php echo $this->get_field_name('widget_images'); ?>" id="<?php echo $this->get_field_id('widget_images'); ?>" class="widefat">
				<option value="Ja"<?php selected( $instance['widget_images'], 'Ja' ); ?>><?php _e('Ja'); ?></option>
				<option value="Nein"<?php selected( $instance['widget_images'], 'Nein' ); ?>><?php _e('Nein'); ?></option>
			</select>
        </p>
		
       <?php
    }

}
function schattenzeilen_init() {

	register_widget('Schattenzeilen_Widget');

}
add_action('widgets_init', 'schattenzeilen_init');
